@@ -1,6 +1,7 @@
 from .base import DBWorker
 from YamlBase.yaml_worker import YamlDataBaseWorker
 import os
+import yaml
 from YamlBase.sql import SQLite
 
 
@@ -8,16 +9,19 @@ class SQLiteWorker(DBWorker):
     tables: list
     schemas: list
 
-    def __init__(self, yaml: YamlDataBaseWorker):
-        super().__init__(yaml)
-        self.db_data = yaml
+    def __init__(self, yaml_db: YamlDataBaseWorker):
+        super().__init__(yaml_db)
+        self.db_data = yaml_db
         self.conn = self.initialize_connection()
-        self.db_identifier = f"{self.db_data.db_info['ip']}_{self.db_data.db_info['db_type']}_" \
-                             f"{self.db_data.db_info['db_name']}.db"
-        self.read_base_information()
+        self.db_identifier = self.create_db_identifier()
+        if not self.check_if_used():
+            self.read_base_information_from_database()
+            self.save_config()
+        else:
+            self.read_base_information_from_config(self.cache_folder + '/' + self.db_identifier + '.yaml')
 
     def check_if_used(self):
-        return self.db_identifier in os.listdir('../scanned_bases')
+        return self.db_identifier + '.yaml' in os.listdir(self.cache_folder)
 
     def initialize_connection(self) -> SQLite:
         return SQLite(self.db_data.db_info['ip'], self.db_data.db_info['db_name'])
@@ -25,27 +29,38 @@ class SQLiteWorker(DBWorker):
     def insert_new_table(self, new_table):
         self.conn.create_table(new_table)
         self.tables = self.conn.get_table_list()
+        self.save_config()
 
     def remove_table(self, table_obj):
         self.conn.remove_table(table_obj.table_name)
-
         self.tables = self.conn.get_table_list()
+        self.save_config()
 
-    def read_base_information(self):
+    def read_base_information_from_database(self):
         self.schemas = self.conn.get_schemas_list()
         self.tables = self.conn.get_table_list()
 
-    def generate_config(self) -> dict:
+    def read_base_information_from_config(self, cfg_path):
+        with open(cfg_path, 'r') as f:
+            cfg = yaml.load(f, yaml.Loader)
+        self.schemas = list(cfg['schemas'].keys())
+        self.tables = []
+        for schema in self.schemas:
+            for table in cfg['schemas'][schema]:
+                self.tables.append(table['name'])
+
+    def save_config(self) -> dict:
         cfg = dict()
         cfg.update(self.db_data.db_info)
 
         cfg['schemas'] = {}
-        cfg['schemas']['main'] = {}
+        cfg['schemas']['main'] = []
         for table in self.tables:
             table_data = self.conn.get_table_data('main', table)
-            cfg['schemas']['main'].update(table_data)
+            cfg['schemas']['main'].append(table_data)
 
-        return cfg
+        with open(self.cache_folder + '/' + self.db_identifier + '.yaml', 'w') as f:
+            yaml.dump(cfg, f)
 
     def check_insert_table_possibility(self, new_table_name) -> bool:
         """
@@ -69,5 +84,4 @@ class SQLiteWorker(DBWorker):
         :param table_name_to_remove: name of table to check
         :return: if table can be removed
         """
-
         return table_name_to_remove in self.tables
