@@ -10,16 +10,13 @@ import os
 
 def main():
 
-    os.chdir('../../')
-
     parser = argparse.ArgumentParser(description='This utility allows you to manage changes to the database using '
                                                  'configurations')
     parser.add_argument('-cfg_db', action='store', dest='cfg_path',
                         help='Path to yaml file with DB config')
 
     args = parser.parse_args()
-    print(os.listdir())
-    base = YBase('base_example.yml')
+    base = YBase(args.cfg_path)
     base.do_actions()
 
 
