@@ -7,12 +7,12 @@ from YamlBase.table_representation import Table, Column
 
 @pytest.fixture
 def test_no_fields_folder():
-    return "../test/configs_for_tests/test_no_fields/"
+    return "./test/configs_for_tests/test_no_fields/"
 
 
 @pytest.fixture
 def test_action_folder():
-    return "../test/configs_for_tests/test_actions/"
+    return "./test/configs_for_tests/test_actions/"
 
 
 @pytest.fixture
@@ -70,7 +70,7 @@ class TestYamlDatabaseWorker:
     def test_parse_yaml(self, correct_first_column_object, correct_second_column_object,
                         correct_third_column_object, correct_first_table_permissions):
 
-        obj = YamlDataBaseWorker('../test/test_base.yml')
+        obj = YamlDataBaseWorker('./test/test_base.yml')
 
         assert obj.tables_info[0].columns[0] == correct_first_column_object
         assert obj.tables_info[0].columns[1] == correct_second_column_object
@@ -87,7 +87,7 @@ class TestYamlActionsWorker:
             YamlActionsWorker('some_file.yaml')
 
     def test_data_parsing(self):
-        obj = YamlActionsWorker('../test/test_actions.yml')
+        obj = YamlActionsWorker('./test/test_db')
         assert obj.action_table == {
             "table1": "insert",
             "table2": "remove"
@@ -95,4 +95,4 @@ class TestYamlActionsWorker:
 
     def test_check_syntax(self, test_action_folder):
         with pytest.raises(ActionConfigSyntaxError):
-            YamlActionsWorker(test_action_folder + 'test_actions_syntax_error.yml')
+            YamlActionsWorker(test_action_folder + 'test_db')
